@@ -68,6 +68,7 @@ void GLWidget::keyPressEvent(QKeyEvent *event) {
 		}
 		if(lopussa && (event->text() == "q")) {
 			keskeytetty = false;
+			pauseGame();
 			hideGame();
 		}
 	}
@@ -146,6 +147,7 @@ void GLWidget::newGame() {
 		sienipaikat.push_back(tmp);
 	}
 	ajankesto = 0;
+	resumeGame();
 }
 
 
@@ -417,6 +419,7 @@ void GLWidget::initializeGL()
     }
 
 
+
 void GLWidget::resizeGL(int w, int h) {
 	glViewport(0,0, (GLint)w, (GLint)h); 
 	projection = new GLfloat[16];
@@ -486,6 +489,7 @@ void GLWidget::paintGL()
 	
 	if(sienipaikat.size() <= 30) {
 		if(!lopussa) {
+			pauseGame();
 			lopussa = true;
 		}
 		QString teodi;
@@ -548,6 +552,7 @@ void GLWidget::Plane() {
 
 void GLWidget::hideGame() {
 	releaseKeyboard();
+	pauseGame();
 	emit onClose();
 }
 
@@ -584,3 +589,13 @@ void GLWidget::pauseGame() {
 void GLWidget::lisaaAikaa() {
 	ajankesto++;
 }
+bool GLWidget::event(QEvent *event) {
+	if(event->type() == QEvent::Leave) {
+		if(!this->isHidden()) pauseGame();
+	}
+	else if(event->type() == QEvent::Enter) {
+		if(!this->isHidden()) resumeGame();
+	}
+	return QGLWidget::event(event);
+}
+
